@@ -1,36 +1,22 @@
 /*
- *  devicelisting.h
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #ifndef DEVICELISTING
 #define DEVICELISTING
 
-//QT
+// QT
 #include <QMap>
 #include <QTreeWidget>
 #include <QTreeWidgetItemIterator>
 
-//Local
+// Local
 #include "soldevice.h"
 
-//Kde
+// Kde
 
 class InfoPanel;
 class DevInfoPlugin;
@@ -54,8 +40,7 @@ public:
     static QTreeWidgetItem *getTreeWidgetItemFromUdi(QTreeWidget *widget, const QString &udi)
     {
         QTreeWidgetItemIterator treeWidget(widget);
-        while (*treeWidget)
-        {
+        while (*treeWidget) {
             SolDevice *item = static_cast<SolDevice *>(*treeWidget);
             if (item->udi() == udi) {
                 return *treeWidget;
@@ -78,7 +63,7 @@ private:
     QAction *allAct = nullptr;
     QAction *relAct = nullptr;
     DevInfoPlugin *status = nullptr;
-    //NicSignals *nicSig;
+    // NicSignals *nicSig;
 
 public Q_SLOTS:
     void currentItemChangedSlot(QTreeWidgetItem *, QTreeWidgetItem *);
@@ -90,4 +75,4 @@ public Q_SLOTS:
     void showRelevantDevicesSlot();
 };
 
-#endif //DEVICELISTING
+#endif // DEVICELISTING
