@@ -1,35 +1,20 @@
 /*
- *  soldevice.h
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #ifndef SOLDEVICE
 #define SOLDEVICE
 
-//QT
-#include <QTreeWidgetItem>
+// QT
 #include <QDebug>
+#include <QTreeWidgetItem>
 
-//Solid
+// Solid
 #include <solid/device.h>
-//KDE
-
+// KDE
 
 class QVListLayout;
 
@@ -45,7 +30,8 @@ public:
     Solid::Device *device();
     Solid::DeviceInterface::Type deviceType() const;
 
-    template<class IFace> const IFace *interface()
+    template<class IFace>
+    const IFace *interface()
     {
         if (deviceSet) {
             IFace *dev = tiedDevice.as<const IFace>();
@@ -58,7 +44,8 @@ public:
         }
     }
 
-    template<class IFace> const IFace *interface(const Solid::Device &device)
+    template<class IFace>
+    const IFace *interface(const Solid::Device &device)
     {
         IFace *dev = device.as<const IFace>();
         if (!dev) {
@@ -67,9 +54,8 @@ public:
         return dev;
     }
 
-    template<class IFace> void createDeviceChildren(
-        QTreeWidgetItem *treeParent, const QString &parentUid,
-        const Solid::DeviceInterface::Type &type)
+    template<class IFace>
+    void createDeviceChildren(QTreeWidgetItem *treeParent, const QString &parentUid, const Solid::DeviceInterface::Type &type)
     {
         const QList<Solid::Device> list = Solid::Device::listFromType(type, parentUid);
 
@@ -95,9 +81,9 @@ public:
     QString udi() const;
     bool isDeviceSet();
 
-    bool operator< (const QTreeWidgetItem & other) const override;
-protected:
+    bool operator<(const QTreeWidgetItem &other) const override;
 
+protected:
     void setDeviceText(const QString &);
 
     virtual void setDefaultDeviceToolTip();
@@ -111,4 +97,4 @@ protected:
     Solid::Device tiedDevice;
 };
 
-#endif //SOLDEVICE
+#endif // SOLDEVICE
