@@ -1,32 +1,19 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright (C) 2015  David Edmundson <david@davidedmundson.co.uk>
+ * SPDX-FileCopyrightText: 2015 David Edmundson <david@davidedmundson.co.uk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
 #include "statisticsprovider.h"
 
-#include <QDebug>
 #include <QDBusArgument>
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusMessage>
 #include <QDBusMetaType> // qDBusRegisterMetaType
 #include <QDBusPendingReply>
+#include <QDebug>
 
 const QDBusArgument &operator<<(QDBusArgument &argument, const HistoryReply &data)
 {
@@ -38,19 +25,20 @@ const QDBusArgument &operator<<(QDBusArgument &argument, const HistoryReply &dat
 
 const QDBusArgument &operator>>(const QDBusArgument &arg, HistoryReply &attrs)
 {
-   arg.beginStructure();
-   arg >> attrs.time >> attrs.value >> attrs.charging;
-   arg.endStructure();
-   return arg;
+    arg.beginStructure();
+    arg >> attrs.time >> attrs.value >> attrs.charging;
+    arg.endStructure();
+    return arg;
 }
 
-StatisticsProvider::StatisticsProvider(QObject *parent) : QObject(parent)
+StatisticsProvider::StatisticsProvider(QObject *parent)
+    : QObject(parent)
 {
     m_type = StatisticsProvider::ChargeType;
     m_duration = 120;
 
     qDBusRegisterMetaType<HistoryReply>();
-    qDBusRegisterMetaType<QList<HistoryReply> >();
+    qDBusRegisterMetaType<QList<HistoryReply>>();
 }
 
 void StatisticsProvider::setDevice(const QString &device)
@@ -89,7 +77,6 @@ void StatisticsProvider::setType(StatisticsProvider::HistoryType type)
     load();
 }
 
-
 void StatisticsProvider::classBegin()
 {
 }
@@ -191,7 +178,7 @@ void StatisticsProvider::load()
         }
 
         foreach (const HistoryReply &r, reply.value()) {
-            if (r.value > 0) { //we get back some values which contain no value, possibly to indicate if charging changes, ignore them
+            if (r.value > 0) { // we get back some values which contain no value, possibly to indicate if charging changes, ignore them
                 m_values.prepend(r);
             }
         }
